@@ -1,5 +1,5 @@
 import argparse
-
+import pkgutil
 from pathlib import Path
 
 
@@ -18,9 +18,13 @@ def main():
     if Path(args.output).is_file():
         print('File exists, overwrite? (y/n)')
         if input() == 'y':
-            with open("predictor-template.py", "r") as template:
-                with open(args.output, 'w') as f:
-                    f.write(template.read())
+            print(__name__)
+            data = pkgutil.get_data(__name__, "predictor-template.py")
+            if data is None:
+                print('Failed to load predictor-template.py')
+                return
+            with open(args.output, 'wb') as f:
+                f.write(data)
         else:
             print('Abort')
     else:
